# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TrafficMirrorFilterRuleArgs', 'TrafficMirrorFilterRule']

@pulumi.input_type
class TrafficMirrorFilterRuleArgs:
    def __init__(__self__, *,
                 destination_cidr_block: pulumi.Input[builtins.str],
                 policy: pulumi.Input[builtins.str],
                 protocol: pulumi.Input[builtins.str],
                 source_cidr_block: pulumi.Input[builtins.str],
                 traffic_direction: pulumi.Input[builtins.str],
                 traffic_mirror_filter_id: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_port_range: Optional[pulumi.Input[builtins.str]] = None,
                 priority: Optional[pulumi.Input[builtins.int]] = None,
                 source_port_range: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a TrafficMirrorFilterRule resource.
        :param pulumi.Input[builtins.str] destination_cidr_block: 目的网段。
        :param pulumi.Input[builtins.str] policy: 流量采集策略。accept：允许。即当镜像源的流量匹配该规则时，复制该流量至镜像目标进行监控分析。reject：拒绝。即当镜像源的流量匹配该规则时，不复制该流量，拒绝对该流量进行监控分析。
        :param pulumi.Input[builtins.str] protocol: 流量的协议。取值如下：all：含TCP、UDP、ICMP协议。tcp：TCP协议。udp：UDP协议。icmp：ICMP协议。
        :param pulumi.Input[builtins.str] source_cidr_block: 流量源网段。
        :param pulumi.Input[builtins.str] traffic_direction: 流量的方向。取值如下：ingress：入向规则。egress：出向规则。
        :param pulumi.Input[builtins.str] traffic_mirror_filter_id: 筛选条件的ID。
        :param pulumi.Input[builtins.str] description: 筛选规则的描述。
        :param pulumi.Input[builtins.str] destination_port_range: 流量目的端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        :param pulumi.Input[builtins.int] priority: 筛选规则的优先级，范围为1-1000。数值越小，优先级越高。默认为1，1为最高优先级。同一筛选条件同一方向的优先级唯一。
        :param pulumi.Input[builtins.str] source_port_range: 流量源端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        """
        pulumi.set(__self__, "destination_cidr_block", destination_cidr_block)
        pulumi.set(__self__, "policy", policy)
        pulumi.set(__self__, "protocol", protocol)
        pulumi.set(__self__, "source_cidr_block", source_cidr_block)
        pulumi.set(__self__, "traffic_direction", traffic_direction)
        pulumi.set(__self__, "traffic_mirror_filter_id", traffic_mirror_filter_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination_port_range is not None:
            pulumi.set(__self__, "destination_port_range", destination_port_range)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if source_port_range is not None:
            pulumi.set(__self__, "source_port_range", source_port_range)

    @property
    @pulumi.getter(name="destinationCidrBlock")
    def destination_cidr_block(self) -> pulumi.Input[builtins.str]:
        """
        目的网段。
        """
        return pulumi.get(self, "destination_cidr_block")

    @destination_cidr_block.setter
    def destination_cidr_block(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "destination_cidr_block", value)

    @property
    @pulumi.getter
    def policy(self) -> pulumi.Input[builtins.str]:
        """
        流量采集策略。accept：允许。即当镜像源的流量匹配该规则时，复制该流量至镜像目标进行监控分析。reject：拒绝。即当镜像源的流量匹配该规则时，不复制该流量，拒绝对该流量进行监控分析。
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[builtins.str]:
        """
        流量的协议。取值如下：all：含TCP、UDP、ICMP协议。tcp：TCP协议。udp：UDP协议。icmp：ICMP协议。
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="sourceCidrBlock")
    def source_cidr_block(self) -> pulumi.Input[builtins.str]:
        """
        流量源网段。
        """
        return pulumi.get(self, "source_cidr_block")

    @source_cidr_block.setter
    def source_cidr_block(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "source_cidr_block", value)

    @property
    @pulumi.getter(name="trafficDirection")
    def traffic_direction(self) -> pulumi.Input[builtins.str]:
        """
        流量的方向。取值如下：ingress：入向规则。egress：出向规则。
        """
        return pulumi.get(self, "traffic_direction")

    @traffic_direction.setter
    def traffic_direction(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "traffic_direction", value)

    @property
    @pulumi.getter(name="trafficMirrorFilterId")
    def traffic_mirror_filter_id(self) -> pulumi.Input[builtins.str]:
        """
        筛选条件的ID。
        """
        return pulumi.get(self, "traffic_mirror_filter_id")

    @traffic_mirror_filter_id.setter
    def traffic_mirror_filter_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "traffic_mirror_filter_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        筛选规则的描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="destinationPortRange")
    def destination_port_range(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流量目的端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        """
        return pulumi.get(self, "destination_port_range")

    @destination_port_range.setter
    def destination_port_range(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "destination_port_range", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        筛选规则的优先级，范围为1-1000。数值越小，优先级越高。默认为1，1为最高优先级。同一筛选条件同一方向的优先级唯一。
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter(name="sourcePortRange")
    def source_port_range(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流量源端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        """
        return pulumi.get(self, "source_port_range")

    @source_port_range.setter
    def source_port_range(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_port_range", value)


@pulumi.input_type
class _TrafficMirrorFilterRuleState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 destination_port_range: Optional[pulumi.Input[builtins.str]] = None,
                 policy: Optional[pulumi.Input[builtins.str]] = None,
                 priority: Optional[pulumi.Input[builtins.int]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 source_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 source_port_range: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 traffic_direction: Optional[pulumi.Input[builtins.str]] = None,
                 traffic_mirror_filter_id: Optional[pulumi.Input[builtins.str]] = None,
                 traffic_mirror_filter_rule_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering TrafficMirrorFilterRule resources.
        :param pulumi.Input[builtins.str] description: 筛选规则的描述。
        :param pulumi.Input[builtins.str] destination_cidr_block: 目的网段。
        :param pulumi.Input[builtins.str] destination_port_range: 流量目的端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        :param pulumi.Input[builtins.str] policy: 流量采集策略。accept：允许。即当镜像源的流量匹配该规则时，复制该流量至镜像目标进行监控分析。reject：拒绝。即当镜像源的流量匹配该规则时，不复制该流量，拒绝对该流量进行监控分析。
        :param pulumi.Input[builtins.int] priority: 筛选规则的优先级，范围为1-1000。数值越小，优先级越高。默认为1，1为最高优先级。同一筛选条件同一方向的优先级唯一。
        :param pulumi.Input[builtins.str] protocol: 流量的协议。取值如下：all：含TCP、UDP、ICMP协议。tcp：TCP协议。udp：UDP协议。icmp：ICMP协议。
        :param pulumi.Input[builtins.str] source_cidr_block: 流量源网段。
        :param pulumi.Input[builtins.str] source_port_range: 流量源端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        :param pulumi.Input[builtins.str] status: 筛选规则的状态。Available：可用。Deleting：删除中。Creating：创建中。Pending：修改中。
        :param pulumi.Input[builtins.str] traffic_direction: 流量的方向。取值如下：ingress：入向规则。egress：出向规则。
        :param pulumi.Input[builtins.str] traffic_mirror_filter_id: 筛选条件的ID。
        :param pulumi.Input[builtins.str] traffic_mirror_filter_rule_id: 筛选规则的ID。
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination_cidr_block is not None:
            pulumi.set(__self__, "destination_cidr_block", destination_cidr_block)
        if destination_port_range is not None:
            pulumi.set(__self__, "destination_port_range", destination_port_range)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if source_cidr_block is not None:
            pulumi.set(__self__, "source_cidr_block", source_cidr_block)
        if source_port_range is not None:
            pulumi.set(__self__, "source_port_range", source_port_range)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if traffic_direction is not None:
            pulumi.set(__self__, "traffic_direction", traffic_direction)
        if traffic_mirror_filter_id is not None:
            pulumi.set(__self__, "traffic_mirror_filter_id", traffic_mirror_filter_id)
        if traffic_mirror_filter_rule_id is not None:
            pulumi.set(__self__, "traffic_mirror_filter_rule_id", traffic_mirror_filter_rule_id)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        筛选规则的描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="destinationCidrBlock")
    def destination_cidr_block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        目的网段。
        """
        return pulumi.get(self, "destination_cidr_block")

    @destination_cidr_block.setter
    def destination_cidr_block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "destination_cidr_block", value)

    @property
    @pulumi.getter(name="destinationPortRange")
    def destination_port_range(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流量目的端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        """
        return pulumi.get(self, "destination_port_range")

    @destination_port_range.setter
    def destination_port_range(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "destination_port_range", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流量采集策略。accept：允许。即当镜像源的流量匹配该规则时，复制该流量至镜像目标进行监控分析。reject：拒绝。即当镜像源的流量匹配该规则时，不复制该流量，拒绝对该流量进行监控分析。
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        筛选规则的优先级，范围为1-1000。数值越小，优先级越高。默认为1，1为最高优先级。同一筛选条件同一方向的优先级唯一。
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流量的协议。取值如下：all：含TCP、UDP、ICMP协议。tcp：TCP协议。udp：UDP协议。icmp：ICMP协议。
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="sourceCidrBlock")
    def source_cidr_block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流量源网段。
        """
        return pulumi.get(self, "source_cidr_block")

    @source_cidr_block.setter
    def source_cidr_block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_cidr_block", value)

    @property
    @pulumi.getter(name="sourcePortRange")
    def source_port_range(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流量源端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        """
        return pulumi.get(self, "source_port_range")

    @source_port_range.setter
    def source_port_range(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_port_range", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        筛选规则的状态。Available：可用。Deleting：删除中。Creating：创建中。Pending：修改中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="trafficDirection")
    def traffic_direction(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流量的方向。取值如下：ingress：入向规则。egress：出向规则。
        """
        return pulumi.get(self, "traffic_direction")

    @traffic_direction.setter
    def traffic_direction(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "traffic_direction", value)

    @property
    @pulumi.getter(name="trafficMirrorFilterId")
    def traffic_mirror_filter_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        筛选条件的ID。
        """
        return pulumi.get(self, "traffic_mirror_filter_id")

    @traffic_mirror_filter_id.setter
    def traffic_mirror_filter_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "traffic_mirror_filter_id", value)

    @property
    @pulumi.getter(name="trafficMirrorFilterRuleId")
    def traffic_mirror_filter_rule_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        筛选规则的ID。
        """
        return pulumi.get(self, "traffic_mirror_filter_rule_id")

    @traffic_mirror_filter_rule_id.setter
    def traffic_mirror_filter_rule_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "traffic_mirror_filter_rule_id", value)


@pulumi.type_token("bytepluscc:vpc/trafficMirrorFilterRule:TrafficMirrorFilterRule")
class TrafficMirrorFilterRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 destination_port_range: Optional[pulumi.Input[builtins.str]] = None,
                 policy: Optional[pulumi.Input[builtins.str]] = None,
                 priority: Optional[pulumi.Input[builtins.int]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 source_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 source_port_range: Optional[pulumi.Input[builtins.str]] = None,
                 traffic_direction: Optional[pulumi.Input[builtins.str]] = None,
                 traffic_mirror_filter_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        筛选条件由筛选规则组成，分为入向筛选规则和出向筛选规则。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_pc_traffic_mirror_filter_rule_demo = bytepluscc.vpc.TrafficMirrorFilterRule("VPCTrafficMirrorFilterRuleDemo",
            description="test",
            destination_cidr_block="10.*.*.0/24",
            destination_port_range="80/80",
            policy="accept",
            priority=1,
            protocol="tcp",
            source_cidr_block="10.*.*.0/24",
            source_port_range="80/80",
            traffic_direction="ingress",
            traffic_mirror_filter_id="tmf-3nqp5bt6a3dog931exxxxx")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/trafficMirrorFilterRule:TrafficMirrorFilterRule example "traffic_mirror_filter_id|traffic_mirror_filter_rule_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 筛选规则的描述。
        :param pulumi.Input[builtins.str] destination_cidr_block: 目的网段。
        :param pulumi.Input[builtins.str] destination_port_range: 流量目的端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        :param pulumi.Input[builtins.str] policy: 流量采集策略。accept：允许。即当镜像源的流量匹配该规则时，复制该流量至镜像目标进行监控分析。reject：拒绝。即当镜像源的流量匹配该规则时，不复制该流量，拒绝对该流量进行监控分析。
        :param pulumi.Input[builtins.int] priority: 筛选规则的优先级，范围为1-1000。数值越小，优先级越高。默认为1，1为最高优先级。同一筛选条件同一方向的优先级唯一。
        :param pulumi.Input[builtins.str] protocol: 流量的协议。取值如下：all：含TCP、UDP、ICMP协议。tcp：TCP协议。udp：UDP协议。icmp：ICMP协议。
        :param pulumi.Input[builtins.str] source_cidr_block: 流量源网段。
        :param pulumi.Input[builtins.str] source_port_range: 流量源端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        :param pulumi.Input[builtins.str] traffic_direction: 流量的方向。取值如下：ingress：入向规则。egress：出向规则。
        :param pulumi.Input[builtins.str] traffic_mirror_filter_id: 筛选条件的ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TrafficMirrorFilterRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        筛选条件由筛选规则组成，分为入向筛选规则和出向筛选规则。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_pc_traffic_mirror_filter_rule_demo = bytepluscc.vpc.TrafficMirrorFilterRule("VPCTrafficMirrorFilterRuleDemo",
            description="test",
            destination_cidr_block="10.*.*.0/24",
            destination_port_range="80/80",
            policy="accept",
            priority=1,
            protocol="tcp",
            source_cidr_block="10.*.*.0/24",
            source_port_range="80/80",
            traffic_direction="ingress",
            traffic_mirror_filter_id="tmf-3nqp5bt6a3dog931exxxxx")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/trafficMirrorFilterRule:TrafficMirrorFilterRule example "traffic_mirror_filter_id|traffic_mirror_filter_rule_id"
        ```

        :param str resource_name: The name of the resource.
        :param TrafficMirrorFilterRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TrafficMirrorFilterRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 destination_port_range: Optional[pulumi.Input[builtins.str]] = None,
                 policy: Optional[pulumi.Input[builtins.str]] = None,
                 priority: Optional[pulumi.Input[builtins.int]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 source_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 source_port_range: Optional[pulumi.Input[builtins.str]] = None,
                 traffic_direction: Optional[pulumi.Input[builtins.str]] = None,
                 traffic_mirror_filter_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TrafficMirrorFilterRuleArgs.__new__(TrafficMirrorFilterRuleArgs)

            __props__.__dict__["description"] = description
            if destination_cidr_block is None and not opts.urn:
                raise TypeError("Missing required property 'destination_cidr_block'")
            __props__.__dict__["destination_cidr_block"] = destination_cidr_block
            __props__.__dict__["destination_port_range"] = destination_port_range
            if policy is None and not opts.urn:
                raise TypeError("Missing required property 'policy'")
            __props__.__dict__["policy"] = policy
            __props__.__dict__["priority"] = priority
            if protocol is None and not opts.urn:
                raise TypeError("Missing required property 'protocol'")
            __props__.__dict__["protocol"] = protocol
            if source_cidr_block is None and not opts.urn:
                raise TypeError("Missing required property 'source_cidr_block'")
            __props__.__dict__["source_cidr_block"] = source_cidr_block
            __props__.__dict__["source_port_range"] = source_port_range
            if traffic_direction is None and not opts.urn:
                raise TypeError("Missing required property 'traffic_direction'")
            __props__.__dict__["traffic_direction"] = traffic_direction
            if traffic_mirror_filter_id is None and not opts.urn:
                raise TypeError("Missing required property 'traffic_mirror_filter_id'")
            __props__.__dict__["traffic_mirror_filter_id"] = traffic_mirror_filter_id
            __props__.__dict__["status"] = None
            __props__.__dict__["traffic_mirror_filter_rule_id"] = None
        super(TrafficMirrorFilterRule, __self__).__init__(
            'bytepluscc:vpc/trafficMirrorFilterRule:TrafficMirrorFilterRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            destination_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
            destination_port_range: Optional[pulumi.Input[builtins.str]] = None,
            policy: Optional[pulumi.Input[builtins.str]] = None,
            priority: Optional[pulumi.Input[builtins.int]] = None,
            protocol: Optional[pulumi.Input[builtins.str]] = None,
            source_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
            source_port_range: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            traffic_direction: Optional[pulumi.Input[builtins.str]] = None,
            traffic_mirror_filter_id: Optional[pulumi.Input[builtins.str]] = None,
            traffic_mirror_filter_rule_id: Optional[pulumi.Input[builtins.str]] = None) -> 'TrafficMirrorFilterRule':
        """
        Get an existing TrafficMirrorFilterRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 筛选规则的描述。
        :param pulumi.Input[builtins.str] destination_cidr_block: 目的网段。
        :param pulumi.Input[builtins.str] destination_port_range: 流量目的端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        :param pulumi.Input[builtins.str] policy: 流量采集策略。accept：允许。即当镜像源的流量匹配该规则时，复制该流量至镜像目标进行监控分析。reject：拒绝。即当镜像源的流量匹配该规则时，不复制该流量，拒绝对该流量进行监控分析。
        :param pulumi.Input[builtins.int] priority: 筛选规则的优先级，范围为1-1000。数值越小，优先级越高。默认为1，1为最高优先级。同一筛选条件同一方向的优先级唯一。
        :param pulumi.Input[builtins.str] protocol: 流量的协议。取值如下：all：含TCP、UDP、ICMP协议。tcp：TCP协议。udp：UDP协议。icmp：ICMP协议。
        :param pulumi.Input[builtins.str] source_cidr_block: 流量源网段。
        :param pulumi.Input[builtins.str] source_port_range: 流量源端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        :param pulumi.Input[builtins.str] status: 筛选规则的状态。Available：可用。Deleting：删除中。Creating：创建中。Pending：修改中。
        :param pulumi.Input[builtins.str] traffic_direction: 流量的方向。取值如下：ingress：入向规则。egress：出向规则。
        :param pulumi.Input[builtins.str] traffic_mirror_filter_id: 筛选条件的ID。
        :param pulumi.Input[builtins.str] traffic_mirror_filter_rule_id: 筛选规则的ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TrafficMirrorFilterRuleState.__new__(_TrafficMirrorFilterRuleState)

        __props__.__dict__["description"] = description
        __props__.__dict__["destination_cidr_block"] = destination_cidr_block
        __props__.__dict__["destination_port_range"] = destination_port_range
        __props__.__dict__["policy"] = policy
        __props__.__dict__["priority"] = priority
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["source_cidr_block"] = source_cidr_block
        __props__.__dict__["source_port_range"] = source_port_range
        __props__.__dict__["status"] = status
        __props__.__dict__["traffic_direction"] = traffic_direction
        __props__.__dict__["traffic_mirror_filter_id"] = traffic_mirror_filter_id
        __props__.__dict__["traffic_mirror_filter_rule_id"] = traffic_mirror_filter_rule_id
        return TrafficMirrorFilterRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        筛选规则的描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="destinationCidrBlock")
    def destination_cidr_block(self) -> pulumi.Output[builtins.str]:
        """
        目的网段。
        """
        return pulumi.get(self, "destination_cidr_block")

    @property
    @pulumi.getter(name="destinationPortRange")
    def destination_port_range(self) -> pulumi.Output[builtins.str]:
        """
        流量目的端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        """
        return pulumi.get(self, "destination_port_range")

    @property
    @pulumi.getter
    def policy(self) -> pulumi.Output[builtins.str]:
        """
        流量采集策略。accept：允许。即当镜像源的流量匹配该规则时，复制该流量至镜像目标进行监控分析。reject：拒绝。即当镜像源的流量匹配该规则时，不复制该流量，拒绝对该流量进行监控分析。
        """
        return pulumi.get(self, "policy")

    @property
    @pulumi.getter
    def priority(self) -> pulumi.Output[builtins.int]:
        """
        筛选规则的优先级，范围为1-1000。数值越小，优先级越高。默认为1，1为最高优先级。同一筛选条件同一方向的优先级唯一。
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[builtins.str]:
        """
        流量的协议。取值如下：all：含TCP、UDP、ICMP协议。tcp：TCP协议。udp：UDP协议。icmp：ICMP协议。
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="sourceCidrBlock")
    def source_cidr_block(self) -> pulumi.Output[builtins.str]:
        """
        流量源网段。
        """
        return pulumi.get(self, "source_cidr_block")

    @property
    @pulumi.getter(name="sourcePortRange")
    def source_port_range(self) -> pulumi.Output[builtins.str]:
        """
        流量源端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        """
        return pulumi.get(self, "source_port_range")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        筛选规则的状态。Available：可用。Deleting：删除中。Creating：创建中。Pending：修改中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="trafficDirection")
    def traffic_direction(self) -> pulumi.Output[builtins.str]:
        """
        流量的方向。取值如下：ingress：入向规则。egress：出向规则。
        """
        return pulumi.get(self, "traffic_direction")

    @property
    @pulumi.getter(name="trafficMirrorFilterId")
    def traffic_mirror_filter_id(self) -> pulumi.Output[builtins.str]:
        """
        筛选条件的ID。
        """
        return pulumi.get(self, "traffic_mirror_filter_id")

    @property
    @pulumi.getter(name="trafficMirrorFilterRuleId")
    def traffic_mirror_filter_rule_id(self) -> pulumi.Output[builtins.str]:
        """
        筛选规则的ID。
        """
        return pulumi.get(self, "traffic_mirror_filter_rule_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceChargeDetailArgs',
    'InstanceChargeDetailArgsDict',
    'InstanceEndpointArgs',
    'InstanceEndpointArgsDict',
    'InstanceTagArgs',
    'InstanceTagArgsDict',
    'PublicAddressChargeDetailArgs',
    'PublicAddressChargeDetailArgsDict',
    'PublicAddressEndpointArgs',
    'PublicAddressEndpointArgsDict',
    'PublicAddressTagArgs',
    'PublicAddressTagArgsDict',
]

MYPY = False

if not MYPY:
    class InstanceChargeDetailArgsDict(TypedDict):
        auto_renew: NotRequired[pulumi.Input[builtins.bool]]
        """
        包年包月实例到期后是否自动续费。
        """
        charge_end_time: NotRequired[pulumi.Input[builtins.str]]
        """
        实例的结束计费时间，时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        charge_expire_time: NotRequired[pulumi.Input[builtins.str]]
        """
        包年包月实例的到期时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        charge_start_time: NotRequired[pulumi.Input[builtins.str]]
        """
        实例的开始计费时间，时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        charge_status: NotRequired[pulumi.Input[builtins.str]]
        """
        实例的计费状态。包括：Normal：正常，Overdue：按量计费欠费，Expired：包年包月到期。
        """
        charge_type: NotRequired[pulumi.Input[builtins.str]]
        """
        实例的计费类型。支持的类型包括：PostPaid ：按量付费，PrePaid：包年包月。
        """
        overdue_reclaim_time: NotRequired[pulumi.Input[builtins.str]]
        """
        实例欠费关停后的预计释放时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        overdue_time: NotRequired[pulumi.Input[builtins.str]]
        """
        实例的欠费关停时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        period: NotRequired[pulumi.Input[builtins.int]]
        """
        包年包月类型实例的购买时长。PeriodUnit 指定为 Month 时，取值范围为 1~9。PeriodUnit 指定为 Year 时，取值范围为 1~3。
        """
        period_unit: NotRequired[pulumi.Input[builtins.str]]
        """
        购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        """
elif False:
    InstanceChargeDetailArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceChargeDetailArgs:
    def __init__(__self__, *,
                 auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
                 charge_end_time: Optional[pulumi.Input[builtins.str]] = None,
                 charge_expire_time: Optional[pulumi.Input[builtins.str]] = None,
                 charge_start_time: Optional[pulumi.Input[builtins.str]] = None,
                 charge_status: Optional[pulumi.Input[builtins.str]] = None,
                 charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 overdue_reclaim_time: Optional[pulumi.Input[builtins.str]] = None,
                 overdue_time: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.bool] auto_renew: 包年包月实例到期后是否自动续费。
        :param pulumi.Input[builtins.str] charge_end_time: 实例的结束计费时间，时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        :param pulumi.Input[builtins.str] charge_expire_time: 包年包月实例的到期时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        :param pulumi.Input[builtins.str] charge_start_time: 实例的开始计费时间，时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        :param pulumi.Input[builtins.str] charge_status: 实例的计费状态。包括：Normal：正常，Overdue：按量计费欠费，Expired：包年包月到期。
        :param pulumi.Input[builtins.str] charge_type: 实例的计费类型。支持的类型包括：PostPaid ：按量付费，PrePaid：包年包月。
        :param pulumi.Input[builtins.str] overdue_reclaim_time: 实例欠费关停后的预计释放时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        :param pulumi.Input[builtins.str] overdue_time: 实例的欠费关停时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        :param pulumi.Input[builtins.int] period: 包年包月类型实例的购买时长。PeriodUnit 指定为 Month 时，取值范围为 1~9。PeriodUnit 指定为 Year 时，取值范围为 1~3。
        :param pulumi.Input[builtins.str] period_unit: 购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        """
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if charge_end_time is not None:
            pulumi.set(__self__, "charge_end_time", charge_end_time)
        if charge_expire_time is not None:
            pulumi.set(__self__, "charge_expire_time", charge_expire_time)
        if charge_start_time is not None:
            pulumi.set(__self__, "charge_start_time", charge_start_time)
        if charge_status is not None:
            pulumi.set(__self__, "charge_status", charge_status)
        if charge_type is not None:
            pulumi.set(__self__, "charge_type", charge_type)
        if overdue_reclaim_time is not None:
            pulumi.set(__self__, "overdue_reclaim_time", overdue_reclaim_time)
        if overdue_time is not None:
            pulumi.set(__self__, "overdue_time", overdue_time)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        包年包月实例到期后是否自动续费。
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="chargeEndTime")
    def charge_end_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的结束计费时间，时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        return pulumi.get(self, "charge_end_time")

    @charge_end_time.setter
    def charge_end_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_end_time", value)

    @property
    @pulumi.getter(name="chargeExpireTime")
    def charge_expire_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        包年包月实例的到期时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        return pulumi.get(self, "charge_expire_time")

    @charge_expire_time.setter
    def charge_expire_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_expire_time", value)

    @property
    @pulumi.getter(name="chargeStartTime")
    def charge_start_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的开始计费时间，时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        return pulumi.get(self, "charge_start_time")

    @charge_start_time.setter
    def charge_start_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_start_time", value)

    @property
    @pulumi.getter(name="chargeStatus")
    def charge_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的计费状态。包括：Normal：正常，Overdue：按量计费欠费，Expired：包年包月到期。
        """
        return pulumi.get(self, "charge_status")

    @charge_status.setter
    def charge_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_status", value)

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的计费类型。支持的类型包括：PostPaid ：按量付费，PrePaid：包年包月。
        """
        return pulumi.get(self, "charge_type")

    @charge_type.setter
    def charge_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_type", value)

    @property
    @pulumi.getter(name="overdueReclaimTime")
    def overdue_reclaim_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例欠费关停后的预计释放时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        return pulumi.get(self, "overdue_reclaim_time")

    @overdue_reclaim_time.setter
    def overdue_reclaim_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "overdue_reclaim_time", value)

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的欠费关停时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        return pulumi.get(self, "overdue_time")

    @overdue_time.setter
    def overdue_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "overdue_time", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        包年包月类型实例的购买时长。PeriodUnit 指定为 Month 时，取值范围为 1~9。PeriodUnit 指定为 Year 时，取值范围为 1~3。
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period_unit", value)


if not MYPY:
    class InstanceEndpointArgsDict(TypedDict):
        endpoint_type: NotRequired[pulumi.Input[builtins.str]]
        """
        实例的接入点类型。RabbitMQ实例提供的接入点类型包括：WEB：Web UI 接入点，AMQP0*9*1：AMQP 接入点，MQTT：MQTT接入点，WEB_MQTT：WEB ，MQTT 接入点，STOMP：STOMP 接入点。
        """
        internal_endpoint: NotRequired[pulumi.Input[builtins.str]]
        """
        实例的私网访问域名。
        """
        internal_ip_endpoint: NotRequired[pulumi.Input[builtins.str]]
        """
        公共服务区 IP 接入点。
        """
        network_type: NotRequired[pulumi.Input[builtins.str]]
        """
        接入点的网络类型。PrivateNetwork 表示私有网络 VPC。
        """
        public_endpoint: NotRequired[pulumi.Input[builtins.str]]
        """
        实例公网访问域名。仅在开启公网访问之后显示。
        """
elif False:
    InstanceEndpointArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceEndpointArgs:
    def __init__(__self__, *,
                 endpoint_type: Optional[pulumi.Input[builtins.str]] = None,
                 internal_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 internal_ip_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 network_type: Optional[pulumi.Input[builtins.str]] = None,
                 public_endpoint: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] endpoint_type: 实例的接入点类型。RabbitMQ实例提供的接入点类型包括：WEB：Web UI 接入点，AMQP0*9*1：AMQP 接入点，MQTT：MQTT接入点，WEB_MQTT：WEB ，MQTT 接入点，STOMP：STOMP 接入点。
        :param pulumi.Input[builtins.str] internal_endpoint: 实例的私网访问域名。
        :param pulumi.Input[builtins.str] internal_ip_endpoint: 公共服务区 IP 接入点。
        :param pulumi.Input[builtins.str] network_type: 接入点的网络类型。PrivateNetwork 表示私有网络 VPC。
        :param pulumi.Input[builtins.str] public_endpoint: 实例公网访问域名。仅在开启公网访问之后显示。
        """
        if endpoint_type is not None:
            pulumi.set(__self__, "endpoint_type", endpoint_type)
        if internal_endpoint is not None:
            pulumi.set(__self__, "internal_endpoint", internal_endpoint)
        if internal_ip_endpoint is not None:
            pulumi.set(__self__, "internal_ip_endpoint", internal_ip_endpoint)
        if network_type is not None:
            pulumi.set(__self__, "network_type", network_type)
        if public_endpoint is not None:
            pulumi.set(__self__, "public_endpoint", public_endpoint)

    @property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的接入点类型。RabbitMQ实例提供的接入点类型包括：WEB：Web UI 接入点，AMQP0*9*1：AMQP 接入点，MQTT：MQTT接入点，WEB_MQTT：WEB ，MQTT 接入点，STOMP：STOMP 接入点。
        """
        return pulumi.get(self, "endpoint_type")

    @endpoint_type.setter
    def endpoint_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "endpoint_type", value)

    @property
    @pulumi.getter(name="internalEndpoint")
    def internal_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的私网访问域名。
        """
        return pulumi.get(self, "internal_endpoint")

    @internal_endpoint.setter
    def internal_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "internal_endpoint", value)

    @property
    @pulumi.getter(name="internalIpEndpoint")
    def internal_ip_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        公共服务区 IP 接入点。
        """
        return pulumi.get(self, "internal_ip_endpoint")

    @internal_ip_endpoint.setter
    def internal_ip_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "internal_ip_endpoint", value)

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        接入点的网络类型。PrivateNetwork 表示私有网络 VPC。
        """
        return pulumi.get(self, "network_type")

    @network_type.setter
    def network_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_type", value)

    @property
    @pulumi.getter(name="publicEndpoint")
    def public_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例公网访问域名。仅在开启公网访问之后显示。
        """
        return pulumi.get(self, "public_endpoint")

    @public_endpoint.setter
    def public_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "public_endpoint", value)


if not MYPY:
    class InstanceTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签的键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签的值。
        """
elif False:
    InstanceTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签的键。
        :param pulumi.Input[builtins.str] value: 标签的值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签的键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签的值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


if not MYPY:
    class PublicAddressChargeDetailArgsDict(TypedDict):
        auto_renew: NotRequired[pulumi.Input[builtins.bool]]
        """
        包年包月实例到期后是否自动续费。
        """
        charge_end_time: NotRequired[pulumi.Input[builtins.str]]
        """
        实例的结束计费时间，时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        charge_expire_time: NotRequired[pulumi.Input[builtins.str]]
        """
        包年包月实例的到期时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        charge_start_time: NotRequired[pulumi.Input[builtins.str]]
        """
        实例的开始计费时间，时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        charge_status: NotRequired[pulumi.Input[builtins.str]]
        """
        实例的计费状态。包括：Normal：正常，Overdue：按量计费欠费，Expired：包年包月到期。
        """
        charge_type: NotRequired[pulumi.Input[builtins.str]]
        """
        实例的计费类型。支持的类型包括：PostPaid ：按量付费，PrePaid：包年包月。
        """
        overdue_reclaim_time: NotRequired[pulumi.Input[builtins.str]]
        """
        实例欠费关停后的预计释放时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        overdue_time: NotRequired[pulumi.Input[builtins.str]]
        """
        实例的欠费关停时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
elif False:
    PublicAddressChargeDetailArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class PublicAddressChargeDetailArgs:
    def __init__(__self__, *,
                 auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
                 charge_end_time: Optional[pulumi.Input[builtins.str]] = None,
                 charge_expire_time: Optional[pulumi.Input[builtins.str]] = None,
                 charge_start_time: Optional[pulumi.Input[builtins.str]] = None,
                 charge_status: Optional[pulumi.Input[builtins.str]] = None,
                 charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 overdue_reclaim_time: Optional[pulumi.Input[builtins.str]] = None,
                 overdue_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.bool] auto_renew: 包年包月实例到期后是否自动续费。
        :param pulumi.Input[builtins.str] charge_end_time: 实例的结束计费时间，时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        :param pulumi.Input[builtins.str] charge_expire_time: 包年包月实例的到期时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        :param pulumi.Input[builtins.str] charge_start_time: 实例的开始计费时间，时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        :param pulumi.Input[builtins.str] charge_status: 实例的计费状态。包括：Normal：正常，Overdue：按量计费欠费，Expired：包年包月到期。
        :param pulumi.Input[builtins.str] charge_type: 实例的计费类型。支持的类型包括：PostPaid ：按量付费，PrePaid：包年包月。
        :param pulumi.Input[builtins.str] overdue_reclaim_time: 实例欠费关停后的预计释放时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        :param pulumi.Input[builtins.str] overdue_time: 实例的欠费关停时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if charge_end_time is not None:
            pulumi.set(__self__, "charge_end_time", charge_end_time)
        if charge_expire_time is not None:
            pulumi.set(__self__, "charge_expire_time", charge_expire_time)
        if charge_start_time is not None:
            pulumi.set(__self__, "charge_start_time", charge_start_time)
        if charge_status is not None:
            pulumi.set(__self__, "charge_status", charge_status)
        if charge_type is not None:
            pulumi.set(__self__, "charge_type", charge_type)
        if overdue_reclaim_time is not None:
            pulumi.set(__self__, "overdue_reclaim_time", overdue_reclaim_time)
        if overdue_time is not None:
            pulumi.set(__self__, "overdue_time", overdue_time)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        包年包月实例到期后是否自动续费。
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="chargeEndTime")
    def charge_end_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的结束计费时间，时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        return pulumi.get(self, "charge_end_time")

    @charge_end_time.setter
    def charge_end_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_end_time", value)

    @property
    @pulumi.getter(name="chargeExpireTime")
    def charge_expire_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        包年包月实例的到期时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        return pulumi.get(self, "charge_expire_time")

    @charge_expire_time.setter
    def charge_expire_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_expire_time", value)

    @property
    @pulumi.getter(name="chargeStartTime")
    def charge_start_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的开始计费时间，时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        return pulumi.get(self, "charge_start_time")

    @charge_start_time.setter
    def charge_start_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_start_time", value)

    @property
    @pulumi.getter(name="chargeStatus")
    def charge_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的计费状态。包括：Normal：正常，Overdue：按量计费欠费，Expired：包年包月到期。
        """
        return pulumi.get(self, "charge_status")

    @charge_status.setter
    def charge_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_status", value)

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的计费类型。支持的类型包括：PostPaid ：按量付费，PrePaid：包年包月。
        """
        return pulumi.get(self, "charge_type")

    @charge_type.setter
    def charge_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_type", value)

    @property
    @pulumi.getter(name="overdueReclaimTime")
    def overdue_reclaim_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例欠费关停后的预计释放时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        return pulumi.get(self, "overdue_reclaim_time")

    @overdue_reclaim_time.setter
    def overdue_reclaim_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "overdue_reclaim_time", value)

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的欠费关停时间。时间显示格式为 YYYY-MM-DD'T'HH:MM:SS'Z'。
        """
        return pulumi.get(self, "overdue_time")

    @overdue_time.setter
    def overdue_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "overdue_time", value)


if not MYPY:
    class PublicAddressEndpointArgsDict(TypedDict):
        endpoint_type: NotRequired[pulumi.Input[builtins.str]]
        """
        实例的接入点类型。RabbitMQ实例提供的接入点类型包括：WEB：Web UI 接入点，AMQP0*9*1：AMQP 接入点，MQTT：MQTT接入点，WEB_MQTT：WEB ，MQTT 接入点，STOMP：STOMP 接入点。
        """
        internal_endpoint: NotRequired[pulumi.Input[builtins.str]]
        """
        实例的私网访问域名。
        """
        internal_ip_endpoint: NotRequired[pulumi.Input[builtins.str]]
        """
        公共服务区 IP 接入点。
        """
        network_type: NotRequired[pulumi.Input[builtins.str]]
        """
        接入点的网络类型。PrivateNetwork 表示私有网络 VPC。
        """
        public_endpoint: NotRequired[pulumi.Input[builtins.str]]
        """
        实例公网访问域名。仅在开启公网访问之后显示。
        """
elif False:
    PublicAddressEndpointArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class PublicAddressEndpointArgs:
    def __init__(__self__, *,
                 endpoint_type: Optional[pulumi.Input[builtins.str]] = None,
                 internal_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 internal_ip_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 network_type: Optional[pulumi.Input[builtins.str]] = None,
                 public_endpoint: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] endpoint_type: 实例的接入点类型。RabbitMQ实例提供的接入点类型包括：WEB：Web UI 接入点，AMQP0*9*1：AMQP 接入点，MQTT：MQTT接入点，WEB_MQTT：WEB ，MQTT 接入点，STOMP：STOMP 接入点。
        :param pulumi.Input[builtins.str] internal_endpoint: 实例的私网访问域名。
        :param pulumi.Input[builtins.str] internal_ip_endpoint: 公共服务区 IP 接入点。
        :param pulumi.Input[builtins.str] network_type: 接入点的网络类型。PrivateNetwork 表示私有网络 VPC。
        :param pulumi.Input[builtins.str] public_endpoint: 实例公网访问域名。仅在开启公网访问之后显示。
        """
        if endpoint_type is not None:
            pulumi.set(__self__, "endpoint_type", endpoint_type)
        if internal_endpoint is not None:
            pulumi.set(__self__, "internal_endpoint", internal_endpoint)
        if internal_ip_endpoint is not None:
            pulumi.set(__self__, "internal_ip_endpoint", internal_ip_endpoint)
        if network_type is not None:
            pulumi.set(__self__, "network_type", network_type)
        if public_endpoint is not None:
            pulumi.set(__self__, "public_endpoint", public_endpoint)

    @property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的接入点类型。RabbitMQ实例提供的接入点类型包括：WEB：Web UI 接入点，AMQP0*9*1：AMQP 接入点，MQTT：MQTT接入点，WEB_MQTT：WEB ，MQTT 接入点，STOMP：STOMP 接入点。
        """
        return pulumi.get(self, "endpoint_type")

    @endpoint_type.setter
    def endpoint_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "endpoint_type", value)

    @property
    @pulumi.getter(name="internalEndpoint")
    def internal_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的私网访问域名。
        """
        return pulumi.get(self, "internal_endpoint")

    @internal_endpoint.setter
    def internal_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "internal_endpoint", value)

    @property
    @pulumi.getter(name="internalIpEndpoint")
    def internal_ip_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        公共服务区 IP 接入点。
        """
        return pulumi.get(self, "internal_ip_endpoint")

    @internal_ip_endpoint.setter
    def internal_ip_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "internal_ip_endpoint", value)

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        接入点的网络类型。PrivateNetwork 表示私有网络 VPC。
        """
        return pulumi.get(self, "network_type")

    @network_type.setter
    def network_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_type", value)

    @property
    @pulumi.getter(name="publicEndpoint")
    def public_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例公网访问域名。仅在开启公网访问之后显示。
        """
        return pulumi.get(self, "public_endpoint")

    @public_endpoint.setter
    def public_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "public_endpoint", value)


if not MYPY:
    class PublicAddressTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签的键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签的值。
        """
elif False:
    PublicAddressTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class PublicAddressTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签的键。
        :param pulumi.Input[builtins.str] value: 标签的值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签的键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签的值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetBackupResult',
    'AwaitableGetBackupResult',
    'get_backup',
    'get_backup_output',
]

@pulumi.output_type
class GetBackupResult:
    """
    A collection of values returned by getBackup.
    """
    def __init__(__self__, backup_end_time=None, backup_file_name=None, backup_file_size=None, backup_id=None, backup_metas=None, backup_method=None, backup_name=None, backup_region=None, backup_start_time=None, backup_status=None, backup_type=None, consistent_time=None, create_type=None, db_engine_version=None, db_table_infos=None, download_status=None, engine_type=None, error_message=None, expired_time=None, id=None, instance_id=None, is_encrypted=None, is_expired=None):
        if backup_end_time and not isinstance(backup_end_time, str):
            raise TypeError("Expected argument 'backup_end_time' to be a str")
        pulumi.set(__self__, "backup_end_time", backup_end_time)
        if backup_file_name and not isinstance(backup_file_name, str):
            raise TypeError("Expected argument 'backup_file_name' to be a str")
        pulumi.set(__self__, "backup_file_name", backup_file_name)
        if backup_file_size and not isinstance(backup_file_size, int):
            raise TypeError("Expected argument 'backup_file_size' to be a int")
        pulumi.set(__self__, "backup_file_size", backup_file_size)
        if backup_id and not isinstance(backup_id, str):
            raise TypeError("Expected argument 'backup_id' to be a str")
        pulumi.set(__self__, "backup_id", backup_id)
        if backup_metas and not isinstance(backup_metas, list):
            raise TypeError("Expected argument 'backup_metas' to be a list")
        pulumi.set(__self__, "backup_metas", backup_metas)
        if backup_method and not isinstance(backup_method, str):
            raise TypeError("Expected argument 'backup_method' to be a str")
        pulumi.set(__self__, "backup_method", backup_method)
        if backup_name and not isinstance(backup_name, str):
            raise TypeError("Expected argument 'backup_name' to be a str")
        pulumi.set(__self__, "backup_name", backup_name)
        if backup_region and not isinstance(backup_region, str):
            raise TypeError("Expected argument 'backup_region' to be a str")
        pulumi.set(__self__, "backup_region", backup_region)
        if backup_start_time and not isinstance(backup_start_time, str):
            raise TypeError("Expected argument 'backup_start_time' to be a str")
        pulumi.set(__self__, "backup_start_time", backup_start_time)
        if backup_status and not isinstance(backup_status, str):
            raise TypeError("Expected argument 'backup_status' to be a str")
        pulumi.set(__self__, "backup_status", backup_status)
        if backup_type and not isinstance(backup_type, str):
            raise TypeError("Expected argument 'backup_type' to be a str")
        pulumi.set(__self__, "backup_type", backup_type)
        if consistent_time and not isinstance(consistent_time, str):
            raise TypeError("Expected argument 'consistent_time' to be a str")
        pulumi.set(__self__, "consistent_time", consistent_time)
        if create_type and not isinstance(create_type, str):
            raise TypeError("Expected argument 'create_type' to be a str")
        pulumi.set(__self__, "create_type", create_type)
        if db_engine_version and not isinstance(db_engine_version, str):
            raise TypeError("Expected argument 'db_engine_version' to be a str")
        pulumi.set(__self__, "db_engine_version", db_engine_version)
        if db_table_infos and not isinstance(db_table_infos, list):
            raise TypeError("Expected argument 'db_table_infos' to be a list")
        pulumi.set(__self__, "db_table_infos", db_table_infos)
        if download_status and not isinstance(download_status, str):
            raise TypeError("Expected argument 'download_status' to be a str")
        pulumi.set(__self__, "download_status", download_status)
        if engine_type and not isinstance(engine_type, str):
            raise TypeError("Expected argument 'engine_type' to be a str")
        pulumi.set(__self__, "engine_type", engine_type)
        if error_message and not isinstance(error_message, str):
            raise TypeError("Expected argument 'error_message' to be a str")
        pulumi.set(__self__, "error_message", error_message)
        if expired_time and not isinstance(expired_time, str):
            raise TypeError("Expected argument 'expired_time' to be a str")
        pulumi.set(__self__, "expired_time", expired_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if is_encrypted and not isinstance(is_encrypted, bool):
            raise TypeError("Expected argument 'is_encrypted' to be a bool")
        pulumi.set(__self__, "is_encrypted", is_encrypted)
        if is_expired and not isinstance(is_expired, bool):
            raise TypeError("Expected argument 'is_expired' to be a bool")
        pulumi.set(__self__, "is_expired", is_expired)

    @property
    @pulumi.getter(name="backupEndTime")
    def backup_end_time(self) -> builtins.str:
        """
        备份创建结束时间（UTC）。
        """
        return pulumi.get(self, "backup_end_time")

    @property
    @pulumi.getter(name="backupFileName")
    def backup_file_name(self) -> builtins.str:
        """
        备份文件名。
        """
        return pulumi.get(self, "backup_file_name")

    @property
    @pulumi.getter(name="backupFileSize")
    def backup_file_size(self) -> builtins.int:
        """
        备份文件大小，单位为字节。
        """
        return pulumi.get(self, "backup_file_size")

    @property
    @pulumi.getter(name="backupId")
    def backup_id(self) -> builtins.str:
        """
        备份 ID。
        """
        return pulumi.get(self, "backup_id")

    @property
    @pulumi.getter(name="backupMetas")
    def backup_metas(self) -> Sequence['outputs.GetBackupBackupMetaResult']:
        """
        创建逻辑备份类型的库表备份时，用于指定要备份的库表信息。
        """
        return pulumi.get(self, "backup_metas")

    @property
    @pulumi.getter(name="backupMethod")
    def backup_method(self) -> builtins.str:
        """
        备份类型，取值：Physical（物理备份）、Logical（逻辑备份）、Snapshot（快照备份）。
        """
        return pulumi.get(self, "backup_method")

    @property
    @pulumi.getter(name="backupName")
    def backup_name(self) -> builtins.str:
        """
        备份的名称。
        """
        return pulumi.get(self, "backup_name")

    @property
    @pulumi.getter(name="backupRegion")
    def backup_region(self) -> builtins.str:
        """
        备份所在区域。
        """
        return pulumi.get(self, "backup_region")

    @property
    @pulumi.getter(name="backupStartTime")
    def backup_start_time(self) -> builtins.str:
        """
        备份创建开始时间（UTC）。
        """
        return pulumi.get(self, "backup_start_time")

    @property
    @pulumi.getter(name="backupStatus")
    def backup_status(self) -> builtins.str:
        """
        备份状态，取值：Success（成功）、Failed（失败）、Running（执行中）。
        """
        return pulumi.get(self, "backup_status")

    @property
    @pulumi.getter(name="backupType")
    def backup_type(self) -> builtins.str:
        """
        备份方式，取值：Full（全量/库表备）、Increment（增量备份）、DumpAll（全库备份）。
        """
        return pulumi.get(self, "backup_type")

    @property
    @pulumi.getter(name="consistentTime")
    def consistent_time(self) -> builtins.str:
        """
        一致性时间点。
        """
        return pulumi.get(self, "consistent_time")

    @property
    @pulumi.getter(name="createType")
    def create_type(self) -> builtins.str:
        """
        备份创建者，取值：System（系统）、User（用户）。
        """
        return pulumi.get(self, "create_type")

    @property
    @pulumi.getter(name="dbEngineVersion")
    def db_engine_version(self) -> builtins.str:
        """
        兼容版本。取值：MySQL*5*7：MySQL 5.7 版本。MySQL*8*0：MySQL 8.0 版本。
        """
        return pulumi.get(self, "db_engine_version")

    @property
    @pulumi.getter(name="dbTableInfos")
    def db_table_infos(self) -> Sequence['outputs.GetBackupDbTableInfoResult']:
        """
        库表信息列表。
        """
        return pulumi.get(self, "db_table_infos")

    @property
    @pulumi.getter(name="downloadStatus")
    def download_status(self) -> builtins.str:
        """
        下载状态。
        """
        return pulumi.get(self, "download_status")

    @property
    @pulumi.getter(name="engineType")
    def engine_type(self) -> builtins.str:
        """
        数据库引擎类型。取值：InnoDB：InnoDB 引擎。RocksDB：RocksDB 引擎。
        """
        return pulumi.get(self, "engine_type")

    @property
    @pulumi.getter(name="errorMessage")
    def error_message(self) -> builtins.str:
        """
        备份失败的错误信息。
        """
        return pulumi.get(self, "error_message")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> builtins.str:
        """
        备份过期时间（UTC）。
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="isEncrypted")
    def is_encrypted(self) -> builtins.bool:
        """
        是否加密。
        """
        return pulumi.get(self, "is_encrypted")

    @property
    @pulumi.getter(name="isExpired")
    def is_expired(self) -> builtins.bool:
        """
        是否已过期。
        """
        return pulumi.get(self, "is_expired")


class AwaitableGetBackupResult(GetBackupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBackupResult(
            backup_end_time=self.backup_end_time,
            backup_file_name=self.backup_file_name,
            backup_file_size=self.backup_file_size,
            backup_id=self.backup_id,
            backup_metas=self.backup_metas,
            backup_method=self.backup_method,
            backup_name=self.backup_name,
            backup_region=self.backup_region,
            backup_start_time=self.backup_start_time,
            backup_status=self.backup_status,
            backup_type=self.backup_type,
            consistent_time=self.consistent_time,
            create_type=self.create_type,
            db_engine_version=self.db_engine_version,
            db_table_infos=self.db_table_infos,
            download_status=self.download_status,
            engine_type=self.engine_type,
            error_message=self.error_message,
            expired_time=self.expired_time,
            id=self.id,
            instance_id=self.instance_id,
            is_encrypted=self.is_encrypted,
            is_expired=self.is_expired)


def get_backup(id: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBackupResult:
    """
    Data Source schema for Byteplus::RDSMySQL::Backup


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:rdsmysql/getBackup:getBackup', __args__, opts=opts, typ=GetBackupResult).value

    return AwaitableGetBackupResult(
        backup_end_time=pulumi.get(__ret__, 'backup_end_time'),
        backup_file_name=pulumi.get(__ret__, 'backup_file_name'),
        backup_file_size=pulumi.get(__ret__, 'backup_file_size'),
        backup_id=pulumi.get(__ret__, 'backup_id'),
        backup_metas=pulumi.get(__ret__, 'backup_metas'),
        backup_method=pulumi.get(__ret__, 'backup_method'),
        backup_name=pulumi.get(__ret__, 'backup_name'),
        backup_region=pulumi.get(__ret__, 'backup_region'),
        backup_start_time=pulumi.get(__ret__, 'backup_start_time'),
        backup_status=pulumi.get(__ret__, 'backup_status'),
        backup_type=pulumi.get(__ret__, 'backup_type'),
        consistent_time=pulumi.get(__ret__, 'consistent_time'),
        create_type=pulumi.get(__ret__, 'create_type'),
        db_engine_version=pulumi.get(__ret__, 'db_engine_version'),
        db_table_infos=pulumi.get(__ret__, 'db_table_infos'),
        download_status=pulumi.get(__ret__, 'download_status'),
        engine_type=pulumi.get(__ret__, 'engine_type'),
        error_message=pulumi.get(__ret__, 'error_message'),
        expired_time=pulumi.get(__ret__, 'expired_time'),
        id=pulumi.get(__ret__, 'id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        is_encrypted=pulumi.get(__ret__, 'is_encrypted'),
        is_expired=pulumi.get(__ret__, 'is_expired'))
def get_backup_output(id: Optional[pulumi.Input[builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBackupResult]:
    """
    Data Source schema for Byteplus::RDSMySQL::Backup


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:rdsmysql/getBackup:getBackup', __args__, opts=opts, typ=GetBackupResult)
    return __ret__.apply(lambda __response__: GetBackupResult(
        backup_end_time=pulumi.get(__response__, 'backup_end_time'),
        backup_file_name=pulumi.get(__response__, 'backup_file_name'),
        backup_file_size=pulumi.get(__response__, 'backup_file_size'),
        backup_id=pulumi.get(__response__, 'backup_id'),
        backup_metas=pulumi.get(__response__, 'backup_metas'),
        backup_method=pulumi.get(__response__, 'backup_method'),
        backup_name=pulumi.get(__response__, 'backup_name'),
        backup_region=pulumi.get(__response__, 'backup_region'),
        backup_start_time=pulumi.get(__response__, 'backup_start_time'),
        backup_status=pulumi.get(__response__, 'backup_status'),
        backup_type=pulumi.get(__response__, 'backup_type'),
        consistent_time=pulumi.get(__response__, 'consistent_time'),
        create_type=pulumi.get(__response__, 'create_type'),
        db_engine_version=pulumi.get(__response__, 'db_engine_version'),
        db_table_infos=pulumi.get(__response__, 'db_table_infos'),
        download_status=pulumi.get(__response__, 'download_status'),
        engine_type=pulumi.get(__response__, 'engine_type'),
        error_message=pulumi.get(__response__, 'error_message'),
        expired_time=pulumi.get(__response__, 'expired_time'),
        id=pulumi.get(__response__, 'id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        is_encrypted=pulumi.get(__response__, 'is_encrypted'),
        is_expired=pulumi.get(__response__, 'is_expired')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AccesskeyArgs', 'Accesskey']

@pulumi.input_type
class AccesskeyArgs:
    def __init__(__self__, *,
                 secret_access_key: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Accesskey resource.
        :param pulumi.Input[builtins.str] secret_access_key: 私有密钥（Secret Access Key）。
        :param pulumi.Input[builtins.str] status: 密钥状态。active代表启用状态，inactive代表禁用状态。
        :param pulumi.Input[builtins.str] user_name: 用户名。用于给指定的IAM用户创建密钥，未指定用户名时则为当前请求身份创建密钥（即主账号请求时为主账号自身创建密钥，IAM用户请求时为IAM用户自身创建密钥。注意：角色不支持为自身创建密钥）。当IAM用户拥有密钥自管理权限时（AccessKeySelfManageAccess），如需为自身创建密钥则需要在请求中传递自身的UserName。
        """
        if secret_access_key is not None:
            pulumi.set(__self__, "secret_access_key", secret_access_key)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有密钥（Secret Access Key）。
        """
        return pulumi.get(self, "secret_access_key")

    @secret_access_key.setter
    def secret_access_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "secret_access_key", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥状态。active代表启用状态，inactive代表禁用状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户名。用于给指定的IAM用户创建密钥，未指定用户名时则为当前请求身份创建密钥（即主账号请求时为主账号自身创建密钥，IAM用户请求时为IAM用户自身创建密钥。注意：角色不支持为自身创建密钥）。当IAM用户拥有密钥自管理权限时（AccessKeySelfManageAccess），如需为自身创建密钥则需要在请求中传递自身的UserName。
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_name", value)


@pulumi.input_type
class _AccesskeyState:
    def __init__(__self__, *,
                 access_key_id: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 last_login_date: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 request_time: Optional[pulumi.Input[builtins.str]] = None,
                 secret_access_key: Optional[pulumi.Input[builtins.str]] = None,
                 service: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Accesskey resources.
        :param pulumi.Input[builtins.str] access_key_id: 密钥ID（Access Key Id）。
        :param pulumi.Input[builtins.str] created_time: 密钥创建时间。时间格式为ISO8601。
        :param pulumi.Input[builtins.str] last_login_date: 最后登录时间。
        :param pulumi.Input[builtins.str] region: API密钥最后访问的地域。
        :param pulumi.Input[builtins.str] request_time: API密钥的最后使用的时间。
        :param pulumi.Input[builtins.str] secret_access_key: 私有密钥（Secret Access Key）。
        :param pulumi.Input[builtins.str] service: API密钥最后访问的服务的英文简称。
        :param pulumi.Input[builtins.str] status: 密钥状态。active代表启用状态，inactive代表禁用状态。
        :param pulumi.Input[builtins.str] updated_time: 密钥更新时间。时间格式为ISO8601。
        :param pulumi.Input[builtins.str] user_name: 用户名。用于给指定的IAM用户创建密钥，未指定用户名时则为当前请求身份创建密钥（即主账号请求时为主账号自身创建密钥，IAM用户请求时为IAM用户自身创建密钥。注意：角色不支持为自身创建密钥）。当IAM用户拥有密钥自管理权限时（AccessKeySelfManageAccess），如需为自身创建密钥则需要在请求中传递自身的UserName。
        """
        if access_key_id is not None:
            pulumi.set(__self__, "access_key_id", access_key_id)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if last_login_date is not None:
            pulumi.set(__self__, "last_login_date", last_login_date)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if request_time is not None:
            pulumi.set(__self__, "request_time", request_time)
        if secret_access_key is not None:
            pulumi.set(__self__, "secret_access_key", secret_access_key)
        if service is not None:
            pulumi.set(__self__, "service", service)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥ID（Access Key Id）。
        """
        return pulumi.get(self, "access_key_id")

    @access_key_id.setter
    def access_key_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "access_key_id", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥创建时间。时间格式为ISO8601。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="lastLoginDate")
    def last_login_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        最后登录时间。
        """
        return pulumi.get(self, "last_login_date")

    @last_login_date.setter
    def last_login_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "last_login_date", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        API密钥最后访问的地域。
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="requestTime")
    def request_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        API密钥的最后使用的时间。
        """
        return pulumi.get(self, "request_time")

    @request_time.setter
    def request_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "request_time", value)

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有密钥（Secret Access Key）。
        """
        return pulumi.get(self, "secret_access_key")

    @secret_access_key.setter
    def secret_access_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "secret_access_key", value)

    @property
    @pulumi.getter
    def service(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        API密钥最后访问的服务的英文简称。
        """
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥状态。active代表启用状态，inactive代表禁用状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥更新时间。时间格式为ISO8601。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户名。用于给指定的IAM用户创建密钥，未指定用户名时则为当前请求身份创建密钥（即主账号请求时为主账号自身创建密钥，IAM用户请求时为IAM用户自身创建密钥。注意：角色不支持为自身创建密钥）。当IAM用户拥有密钥自管理权限时（AccessKeySelfManageAccess），如需为自身创建密钥则需要在请求中传递自身的UserName。
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_name", value)


@pulumi.type_token("bytepluscc:iam/accesskey:Accesskey")
class Accesskey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 secret_access_key: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        访问控制(Identity and Access Management，缩写为IAM)是火山引擎为客户提供的一套权限管理系统，用于控制不同身份对云资源的访问权限。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        accesskey_demo = bytepluscc.iam.Accesskey("AccesskeyDemo", user_name="s2222")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:iam/accesskey:Accesskey example "access_key_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] secret_access_key: 私有密钥（Secret Access Key）。
        :param pulumi.Input[builtins.str] status: 密钥状态。active代表启用状态，inactive代表禁用状态。
        :param pulumi.Input[builtins.str] user_name: 用户名。用于给指定的IAM用户创建密钥，未指定用户名时则为当前请求身份创建密钥（即主账号请求时为主账号自身创建密钥，IAM用户请求时为IAM用户自身创建密钥。注意：角色不支持为自身创建密钥）。当IAM用户拥有密钥自管理权限时（AccessKeySelfManageAccess），如需为自身创建密钥则需要在请求中传递自身的UserName。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AccesskeyArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        访问控制(Identity and Access Management，缩写为IAM)是火山引擎为客户提供的一套权限管理系统，用于控制不同身份对云资源的访问权限。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        accesskey_demo = bytepluscc.iam.Accesskey("AccesskeyDemo", user_name="s2222")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:iam/accesskey:Accesskey example "access_key_id"
        ```

        :param str resource_name: The name of the resource.
        :param AccesskeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccesskeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 secret_access_key: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccesskeyArgs.__new__(AccesskeyArgs)

            __props__.__dict__["secret_access_key"] = secret_access_key
            __props__.__dict__["status"] = status
            __props__.__dict__["user_name"] = user_name
            __props__.__dict__["access_key_id"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["last_login_date"] = None
            __props__.__dict__["region"] = None
            __props__.__dict__["request_time"] = None
            __props__.__dict__["service"] = None
            __props__.__dict__["updated_time"] = None
        super(Accesskey, __self__).__init__(
            'bytepluscc:iam/accesskey:Accesskey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_key_id: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            last_login_date: Optional[pulumi.Input[builtins.str]] = None,
            region: Optional[pulumi.Input[builtins.str]] = None,
            request_time: Optional[pulumi.Input[builtins.str]] = None,
            secret_access_key: Optional[pulumi.Input[builtins.str]] = None,
            service: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            user_name: Optional[pulumi.Input[builtins.str]] = None) -> 'Accesskey':
        """
        Get an existing Accesskey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] access_key_id: 密钥ID（Access Key Id）。
        :param pulumi.Input[builtins.str] created_time: 密钥创建时间。时间格式为ISO8601。
        :param pulumi.Input[builtins.str] last_login_date: 最后登录时间。
        :param pulumi.Input[builtins.str] region: API密钥最后访问的地域。
        :param pulumi.Input[builtins.str] request_time: API密钥的最后使用的时间。
        :param pulumi.Input[builtins.str] secret_access_key: 私有密钥（Secret Access Key）。
        :param pulumi.Input[builtins.str] service: API密钥最后访问的服务的英文简称。
        :param pulumi.Input[builtins.str] status: 密钥状态。active代表启用状态，inactive代表禁用状态。
        :param pulumi.Input[builtins.str] updated_time: 密钥更新时间。时间格式为ISO8601。
        :param pulumi.Input[builtins.str] user_name: 用户名。用于给指定的IAM用户创建密钥，未指定用户名时则为当前请求身份创建密钥（即主账号请求时为主账号自身创建密钥，IAM用户请求时为IAM用户自身创建密钥。注意：角色不支持为自身创建密钥）。当IAM用户拥有密钥自管理权限时（AccessKeySelfManageAccess），如需为自身创建密钥则需要在请求中传递自身的UserName。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccesskeyState.__new__(_AccesskeyState)

        __props__.__dict__["access_key_id"] = access_key_id
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["last_login_date"] = last_login_date
        __props__.__dict__["region"] = region
        __props__.__dict__["request_time"] = request_time
        __props__.__dict__["secret_access_key"] = secret_access_key
        __props__.__dict__["service"] = service
        __props__.__dict__["status"] = status
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["user_name"] = user_name
        return Accesskey(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> pulumi.Output[builtins.str]:
        """
        密钥ID（Access Key Id）。
        """
        return pulumi.get(self, "access_key_id")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        密钥创建时间。时间格式为ISO8601。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="lastLoginDate")
    def last_login_date(self) -> pulumi.Output[builtins.str]:
        """
        最后登录时间。
        """
        return pulumi.get(self, "last_login_date")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[builtins.str]:
        """
        API密钥最后访问的地域。
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="requestTime")
    def request_time(self) -> pulumi.Output[builtins.str]:
        """
        API密钥的最后使用的时间。
        """
        return pulumi.get(self, "request_time")

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> pulumi.Output[builtins.str]:
        """
        私有密钥（Secret Access Key）。
        """
        return pulumi.get(self, "secret_access_key")

    @property
    @pulumi.getter
    def service(self) -> pulumi.Output[builtins.str]:
        """
        API密钥最后访问的服务的英文简称。
        """
        return pulumi.get(self, "service")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        密钥状态。active代表启用状态，inactive代表禁用状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        密钥更新时间。时间格式为ISO8601。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[builtins.str]:
        """
        用户名。用于给指定的IAM用户创建密钥，未指定用户名时则为当前请求身份创建密钥（即主账号请求时为主账号自身创建密钥，IAM用户请求时为IAM用户自身创建密钥。注意：角色不支持为自身创建密钥）。当IAM用户拥有密钥自管理权限时（AccessKeySelfManageAccess），如需为自身创建密钥则需要在请求中传递自身的UserName。
        """
        return pulumi.get(self, "user_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TrafficMirrorSessionArgs', 'TrafficMirrorSession']

@pulumi.input_type
class TrafficMirrorSessionArgs:
    def __init__(__self__, *,
                 network_interface_id: pulumi.Input[builtins.str],
                 priority: pulumi.Input[builtins.int],
                 traffic_mirror_filter_id: pulumi.Input[builtins.str],
                 traffic_mirror_target_id: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 packet_length: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['TrafficMirrorSessionTagArgs']]]] = None,
                 traffic_mirror_session_name: Optional[pulumi.Input[builtins.str]] = None,
                 virtual_network_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a TrafficMirrorSession resource.
        :param pulumi.Input[builtins.str] network_interface_id: 镜像源实例ID，当前只支持ECS的主网卡和辅助网卡。
        :param pulumi.Input[builtins.int] priority: 镜像会话优先级，取值范围1 ～ 32766，同一账户下镜像会话优先级不能重复。
        :param pulumi.Input[builtins.str] traffic_mirror_filter_id: 筛选条件实例ID。
        :param pulumi.Input[builtins.str] traffic_mirror_target_id: 镜像目的实例ID。
        :param pulumi.Input[builtins.str] description: 镜像会话实例描述。
        :param pulumi.Input[builtins.int] packet_length: 镜像会话MTU，超过被截断，取值范围：64～9600。
        :param pulumi.Input[builtins.str] project_name: 所属项目的名称
        :param pulumi.Input[builtins.str] traffic_mirror_session_name: 镜像会话名称。
        :param pulumi.Input[builtins.int] virtual_network_id: 镜像会话VNI，取值范围1 ～ 16777215。
        """
        pulumi.set(__self__, "network_interface_id", network_interface_id)
        pulumi.set(__self__, "priority", priority)
        pulumi.set(__self__, "traffic_mirror_filter_id", traffic_mirror_filter_id)
        pulumi.set(__self__, "traffic_mirror_target_id", traffic_mirror_target_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if packet_length is not None:
            pulumi.set(__self__, "packet_length", packet_length)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if traffic_mirror_session_name is not None:
            pulumi.set(__self__, "traffic_mirror_session_name", traffic_mirror_session_name)
        if virtual_network_id is not None:
            pulumi.set(__self__, "virtual_network_id", virtual_network_id)

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> pulumi.Input[builtins.str]:
        """
        镜像源实例ID，当前只支持ECS的主网卡和辅助网卡。
        """
        return pulumi.get(self, "network_interface_id")

    @network_interface_id.setter
    def network_interface_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "network_interface_id", value)

    @property
    @pulumi.getter
    def priority(self) -> pulumi.Input[builtins.int]:
        """
        镜像会话优先级，取值范围1 ～ 32766，同一账户下镜像会话优先级不能重复。
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter(name="trafficMirrorFilterId")
    def traffic_mirror_filter_id(self) -> pulumi.Input[builtins.str]:
        """
        筛选条件实例ID。
        """
        return pulumi.get(self, "traffic_mirror_filter_id")

    @traffic_mirror_filter_id.setter
    def traffic_mirror_filter_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "traffic_mirror_filter_id", value)

    @property
    @pulumi.getter(name="trafficMirrorTargetId")
    def traffic_mirror_target_id(self) -> pulumi.Input[builtins.str]:
        """
        镜像目的实例ID。
        """
        return pulumi.get(self, "traffic_mirror_target_id")

    @traffic_mirror_target_id.setter
    def traffic_mirror_target_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "traffic_mirror_target_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像会话实例描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="packetLength")
    def packet_length(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        镜像会话MTU，超过被截断，取值范围：64～9600。
        """
        return pulumi.get(self, "packet_length")

    @packet_length.setter
    def packet_length(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "packet_length", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        所属项目的名称
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TrafficMirrorSessionTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TrafficMirrorSessionTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="trafficMirrorSessionName")
    def traffic_mirror_session_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像会话名称。
        """
        return pulumi.get(self, "traffic_mirror_session_name")

    @traffic_mirror_session_name.setter
    def traffic_mirror_session_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "traffic_mirror_session_name", value)

    @property
    @pulumi.getter(name="virtualNetworkId")
    def virtual_network_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        镜像会话VNI，取值范围1 ～ 16777215。
        """
        return pulumi.get(self, "virtual_network_id")

    @virtual_network_id.setter
    def virtual_network_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "virtual_network_id", value)


@pulumi.input_type
class _TrafficMirrorSessionState:
    def __init__(__self__, *,
                 business_status: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 lock_reason: Optional[pulumi.Input[builtins.str]] = None,
                 network_interface_id: Optional[pulumi.Input[builtins.str]] = None,
                 packet_length: Optional[pulumi.Input[builtins.int]] = None,
                 priority: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['TrafficMirrorSessionTagArgs']]]] = None,
                 traffic_mirror_filter_id: Optional[pulumi.Input[builtins.str]] = None,
                 traffic_mirror_session_id: Optional[pulumi.Input[builtins.str]] = None,
                 traffic_mirror_session_name: Optional[pulumi.Input[builtins.str]] = None,
                 traffic_mirror_source_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 traffic_mirror_target_id: Optional[pulumi.Input[builtins.str]] = None,
                 virtual_network_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering TrafficMirrorSession resources.
        :param pulumi.Input[builtins.str] business_status: 会话计费状态。Normal：正常计费中。  - FinancialLocked：欠费锁定。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] description: 镜像会话实例描述。
        :param pulumi.Input[builtins.str] lock_reason: 锁定原因。
        :param pulumi.Input[builtins.str] network_interface_id: 镜像源实例ID，当前只支持ECS的主网卡和辅助网卡。
        :param pulumi.Input[builtins.int] packet_length: 镜像会话MTU，超过被截断，取值范围：64～9600。
        :param pulumi.Input[builtins.int] priority: 镜像会话优先级，取值范围1 ～ 32766，同一账户下镜像会话优先级不能重复。
        :param pulumi.Input[builtins.str] project_name: 所属项目的名称
        :param pulumi.Input[builtins.str] status: 会话状态。
        :param pulumi.Input[builtins.str] traffic_mirror_filter_id: 筛选条件实例ID。
        :param pulumi.Input[builtins.str] traffic_mirror_session_id: 镜像会话实例ID。
        :param pulumi.Input[builtins.str] traffic_mirror_session_name: 镜像会话名称。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] traffic_mirror_source_ids: 镜像源实例列表。
        :param pulumi.Input[builtins.str] traffic_mirror_target_id: 镜像目的实例ID。
        :param pulumi.Input[builtins.int] virtual_network_id: 镜像会话VNI，取值范围1 ～ 16777215。
        """
        if business_status is not None:
            pulumi.set(__self__, "business_status", business_status)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if lock_reason is not None:
            pulumi.set(__self__, "lock_reason", lock_reason)
        if network_interface_id is not None:
            pulumi.set(__self__, "network_interface_id", network_interface_id)
        if packet_length is not None:
            pulumi.set(__self__, "packet_length", packet_length)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if traffic_mirror_filter_id is not None:
            pulumi.set(__self__, "traffic_mirror_filter_id", traffic_mirror_filter_id)
        if traffic_mirror_session_id is not None:
            pulumi.set(__self__, "traffic_mirror_session_id", traffic_mirror_session_id)
        if traffic_mirror_session_name is not None:
            pulumi.set(__self__, "traffic_mirror_session_name", traffic_mirror_session_name)
        if traffic_mirror_source_ids is not None:
            pulumi.set(__self__, "traffic_mirror_source_ids", traffic_mirror_source_ids)
        if traffic_mirror_target_id is not None:
            pulumi.set(__self__, "traffic_mirror_target_id", traffic_mirror_target_id)
        if virtual_network_id is not None:
            pulumi.set(__self__, "virtual_network_id", virtual_network_id)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        会话计费状态。Normal：正常计费中。  - FinancialLocked：欠费锁定。
        """
        return pulumi.get(self, "business_status")

    @business_status.setter
    def business_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "business_status", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像会话实例描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        锁定原因。
        """
        return pulumi.get(self, "lock_reason")

    @lock_reason.setter
    def lock_reason(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lock_reason", value)

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像源实例ID，当前只支持ECS的主网卡和辅助网卡。
        """
        return pulumi.get(self, "network_interface_id")

    @network_interface_id.setter
    def network_interface_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_interface_id", value)

    @property
    @pulumi.getter(name="packetLength")
    def packet_length(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        镜像会话MTU，超过被截断，取值范围：64～9600。
        """
        return pulumi.get(self, "packet_length")

    @packet_length.setter
    def packet_length(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "packet_length", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        镜像会话优先级，取值范围1 ～ 32766，同一账户下镜像会话优先级不能重复。
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        所属项目的名称
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        会话状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TrafficMirrorSessionTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TrafficMirrorSessionTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="trafficMirrorFilterId")
    def traffic_mirror_filter_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        筛选条件实例ID。
        """
        return pulumi.get(self, "traffic_mirror_filter_id")

    @traffic_mirror_filter_id.setter
    def traffic_mirror_filter_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "traffic_mirror_filter_id", value)

    @property
    @pulumi.getter(name="trafficMirrorSessionId")
    def traffic_mirror_session_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像会话实例ID。
        """
        return pulumi.get(self, "traffic_mirror_session_id")

    @traffic_mirror_session_id.setter
    def traffic_mirror_session_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "traffic_mirror_session_id", value)

    @property
    @pulumi.getter(name="trafficMirrorSessionName")
    def traffic_mirror_session_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像会话名称。
        """
        return pulumi.get(self, "traffic_mirror_session_name")

    @traffic_mirror_session_name.setter
    def traffic_mirror_session_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "traffic_mirror_session_name", value)

    @property
    @pulumi.getter(name="trafficMirrorSourceIds")
    def traffic_mirror_source_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        镜像源实例列表。
        """
        return pulumi.get(self, "traffic_mirror_source_ids")

    @traffic_mirror_source_ids.setter
    def traffic_mirror_source_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "traffic_mirror_source_ids", value)

    @property
    @pulumi.getter(name="trafficMirrorTargetId")
    def traffic_mirror_target_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像目的实例ID。
        """
        return pulumi.get(self, "traffic_mirror_target_id")

    @traffic_mirror_target_id.setter
    def traffic_mirror_target_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "traffic_mirror_target_id", value)

    @property
    @pulumi.getter(name="virtualNetworkId")
    def virtual_network_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        镜像会话VNI，取值范围1 ～ 16777215。
        """
        return pulumi.get(self, "virtual_network_id")

    @virtual_network_id.setter
    def virtual_network_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "virtual_network_id", value)


@pulumi.type_token("bytepluscc:vpc/trafficMirrorSession:TrafficMirrorSession")
class TrafficMirrorSession(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 network_interface_id: Optional[pulumi.Input[builtins.str]] = None,
                 packet_length: Optional[pulumi.Input[builtins.int]] = None,
                 priority: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TrafficMirrorSessionTagArgs', 'TrafficMirrorSessionTagArgsDict']]]]] = None,
                 traffic_mirror_filter_id: Optional[pulumi.Input[builtins.str]] = None,
                 traffic_mirror_session_name: Optional[pulumi.Input[builtins.str]] = None,
                 traffic_mirror_target_id: Optional[pulumi.Input[builtins.str]] = None,
                 virtual_network_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        镜像会话关联镜像源、镜像目的、筛选条件，使从镜像源复制的流量私网转发到镜像目的，是流量镜像的载体。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_pc_traffic_mirror_session_demo = bytepluscc.vpc.TrafficMirrorSession("VPCTrafficMirrorSessionDemo",
            description="test-description",
            network_interface_id="eni-1a1s0wz7xkm4g8nvexxxxx",
            packet_length=64,
            priority=12,
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }],
            traffic_mirror_filter_id="tmf-bu54sj0bl2bk5h0xxxxx",
            traffic_mirror_session_name="test-1",
            traffic_mirror_target_id="tmt-ij32u0acvta874o8ctxxxxx",
            virtual_network_id=13)
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/trafficMirrorSession:TrafficMirrorSession example "traffic_mirror_session_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 镜像会话实例描述。
        :param pulumi.Input[builtins.str] network_interface_id: 镜像源实例ID，当前只支持ECS的主网卡和辅助网卡。
        :param pulumi.Input[builtins.int] packet_length: 镜像会话MTU，超过被截断，取值范围：64～9600。
        :param pulumi.Input[builtins.int] priority: 镜像会话优先级，取值范围1 ～ 32766，同一账户下镜像会话优先级不能重复。
        :param pulumi.Input[builtins.str] project_name: 所属项目的名称
        :param pulumi.Input[builtins.str] traffic_mirror_filter_id: 筛选条件实例ID。
        :param pulumi.Input[builtins.str] traffic_mirror_session_name: 镜像会话名称。
        :param pulumi.Input[builtins.str] traffic_mirror_target_id: 镜像目的实例ID。
        :param pulumi.Input[builtins.int] virtual_network_id: 镜像会话VNI，取值范围1 ～ 16777215。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TrafficMirrorSessionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        镜像会话关联镜像源、镜像目的、筛选条件，使从镜像源复制的流量私网转发到镜像目的，是流量镜像的载体。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_pc_traffic_mirror_session_demo = bytepluscc.vpc.TrafficMirrorSession("VPCTrafficMirrorSessionDemo",
            description="test-description",
            network_interface_id="eni-1a1s0wz7xkm4g8nvexxxxx",
            packet_length=64,
            priority=12,
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }],
            traffic_mirror_filter_id="tmf-bu54sj0bl2bk5h0xxxxx",
            traffic_mirror_session_name="test-1",
            traffic_mirror_target_id="tmt-ij32u0acvta874o8ctxxxxx",
            virtual_network_id=13)
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/trafficMirrorSession:TrafficMirrorSession example "traffic_mirror_session_id"
        ```

        :param str resource_name: The name of the resource.
        :param TrafficMirrorSessionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TrafficMirrorSessionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 network_interface_id: Optional[pulumi.Input[builtins.str]] = None,
                 packet_length: Optional[pulumi.Input[builtins.int]] = None,
                 priority: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TrafficMirrorSessionTagArgs', 'TrafficMirrorSessionTagArgsDict']]]]] = None,
                 traffic_mirror_filter_id: Optional[pulumi.Input[builtins.str]] = None,
                 traffic_mirror_session_name: Optional[pulumi.Input[builtins.str]] = None,
                 traffic_mirror_target_id: Optional[pulumi.Input[builtins.str]] = None,
                 virtual_network_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TrafficMirrorSessionArgs.__new__(TrafficMirrorSessionArgs)

            __props__.__dict__["description"] = description
            if network_interface_id is None and not opts.urn:
                raise TypeError("Missing required property 'network_interface_id'")
            __props__.__dict__["network_interface_id"] = network_interface_id
            __props__.__dict__["packet_length"] = packet_length
            if priority is None and not opts.urn:
                raise TypeError("Missing required property 'priority'")
            __props__.__dict__["priority"] = priority
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["tags"] = tags
            if traffic_mirror_filter_id is None and not opts.urn:
                raise TypeError("Missing required property 'traffic_mirror_filter_id'")
            __props__.__dict__["traffic_mirror_filter_id"] = traffic_mirror_filter_id
            __props__.__dict__["traffic_mirror_session_name"] = traffic_mirror_session_name
            if traffic_mirror_target_id is None and not opts.urn:
                raise TypeError("Missing required property 'traffic_mirror_target_id'")
            __props__.__dict__["traffic_mirror_target_id"] = traffic_mirror_target_id
            __props__.__dict__["virtual_network_id"] = virtual_network_id
            __props__.__dict__["business_status"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["lock_reason"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["traffic_mirror_session_id"] = None
            __props__.__dict__["traffic_mirror_source_ids"] = None
        super(TrafficMirrorSession, __self__).__init__(
            'bytepluscc:vpc/trafficMirrorSession:TrafficMirrorSession',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            business_status: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            lock_reason: Optional[pulumi.Input[builtins.str]] = None,
            network_interface_id: Optional[pulumi.Input[builtins.str]] = None,
            packet_length: Optional[pulumi.Input[builtins.int]] = None,
            priority: Optional[pulumi.Input[builtins.int]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TrafficMirrorSessionTagArgs', 'TrafficMirrorSessionTagArgsDict']]]]] = None,
            traffic_mirror_filter_id: Optional[pulumi.Input[builtins.str]] = None,
            traffic_mirror_session_id: Optional[pulumi.Input[builtins.str]] = None,
            traffic_mirror_session_name: Optional[pulumi.Input[builtins.str]] = None,
            traffic_mirror_source_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            traffic_mirror_target_id: Optional[pulumi.Input[builtins.str]] = None,
            virtual_network_id: Optional[pulumi.Input[builtins.int]] = None) -> 'TrafficMirrorSession':
        """
        Get an existing TrafficMirrorSession resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] business_status: 会话计费状态。Normal：正常计费中。  - FinancialLocked：欠费锁定。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] description: 镜像会话实例描述。
        :param pulumi.Input[builtins.str] lock_reason: 锁定原因。
        :param pulumi.Input[builtins.str] network_interface_id: 镜像源实例ID，当前只支持ECS的主网卡和辅助网卡。
        :param pulumi.Input[builtins.int] packet_length: 镜像会话MTU，超过被截断，取值范围：64～9600。
        :param pulumi.Input[builtins.int] priority: 镜像会话优先级，取值范围1 ～ 32766，同一账户下镜像会话优先级不能重复。
        :param pulumi.Input[builtins.str] project_name: 所属项目的名称
        :param pulumi.Input[builtins.str] status: 会话状态。
        :param pulumi.Input[builtins.str] traffic_mirror_filter_id: 筛选条件实例ID。
        :param pulumi.Input[builtins.str] traffic_mirror_session_id: 镜像会话实例ID。
        :param pulumi.Input[builtins.str] traffic_mirror_session_name: 镜像会话名称。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] traffic_mirror_source_ids: 镜像源实例列表。
        :param pulumi.Input[builtins.str] traffic_mirror_target_id: 镜像目的实例ID。
        :param pulumi.Input[builtins.int] virtual_network_id: 镜像会话VNI，取值范围1 ～ 16777215。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TrafficMirrorSessionState.__new__(_TrafficMirrorSessionState)

        __props__.__dict__["business_status"] = business_status
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["lock_reason"] = lock_reason
        __props__.__dict__["network_interface_id"] = network_interface_id
        __props__.__dict__["packet_length"] = packet_length
        __props__.__dict__["priority"] = priority
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["traffic_mirror_filter_id"] = traffic_mirror_filter_id
        __props__.__dict__["traffic_mirror_session_id"] = traffic_mirror_session_id
        __props__.__dict__["traffic_mirror_session_name"] = traffic_mirror_session_name
        __props__.__dict__["traffic_mirror_source_ids"] = traffic_mirror_source_ids
        __props__.__dict__["traffic_mirror_target_id"] = traffic_mirror_target_id
        __props__.__dict__["virtual_network_id"] = virtual_network_id
        return TrafficMirrorSession(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> pulumi.Output[builtins.str]:
        """
        会话计费状态。Normal：正常计费中。  - FinancialLocked：欠费锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        镜像会话实例描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> pulumi.Output[builtins.str]:
        """
        锁定原因。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> pulumi.Output[builtins.str]:
        """
        镜像源实例ID，当前只支持ECS的主网卡和辅助网卡。
        """
        return pulumi.get(self, "network_interface_id")

    @property
    @pulumi.getter(name="packetLength")
    def packet_length(self) -> pulumi.Output[builtins.int]:
        """
        镜像会话MTU，超过被截断，取值范围：64～9600。
        """
        return pulumi.get(self, "packet_length")

    @property
    @pulumi.getter
    def priority(self) -> pulumi.Output[builtins.int]:
        """
        镜像会话优先级，取值范围1 ～ 32766，同一账户下镜像会话优先级不能重复。
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        所属项目的名称
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        会话状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.TrafficMirrorSessionTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="trafficMirrorFilterId")
    def traffic_mirror_filter_id(self) -> pulumi.Output[builtins.str]:
        """
        筛选条件实例ID。
        """
        return pulumi.get(self, "traffic_mirror_filter_id")

    @property
    @pulumi.getter(name="trafficMirrorSessionId")
    def traffic_mirror_session_id(self) -> pulumi.Output[builtins.str]:
        """
        镜像会话实例ID。
        """
        return pulumi.get(self, "traffic_mirror_session_id")

    @property
    @pulumi.getter(name="trafficMirrorSessionName")
    def traffic_mirror_session_name(self) -> pulumi.Output[builtins.str]:
        """
        镜像会话名称。
        """
        return pulumi.get(self, "traffic_mirror_session_name")

    @property
    @pulumi.getter(name="trafficMirrorSourceIds")
    def traffic_mirror_source_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        镜像源实例列表。
        """
        return pulumi.get(self, "traffic_mirror_source_ids")

    @property
    @pulumi.getter(name="trafficMirrorTargetId")
    def traffic_mirror_target_id(self) -> pulumi.Output[builtins.str]:
        """
        镜像目的实例ID。
        """
        return pulumi.get(self, "traffic_mirror_target_id")

    @property
    @pulumi.getter(name="virtualNetworkId")
    def virtual_network_id(self) -> pulumi.Output[builtins.int]:
        """
        镜像会话VNI，取值范围1 ～ 16777215。
        """
        return pulumi.get(self, "virtual_network_id")

